Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorThomas Watson2012-08-04 20:48:53 +0000
committerThomas Watson2012-08-04 20:48:53 +0000
commit4486fd747641838456a29d34040cd52cf455277d (patch)
tree0bb9cbf3ac8d546d481689b4eed021ae648cabe7 /bundles/org.eclipse.osgi/container/src/org/eclipse/osgi/container/ModuleContainerAdaptor.java
parent747c370b8bca654fa338a231de2120d692fd74b8 (diff)
downloadrt.equinox.framework-4486fd747641838456a29d34040cd52cf455277d.tar.gz
rt.equinox.framework-4486fd747641838456a29d34040cd52cf455277d.tar.xz
rt.equinox.framework-4486fd747641838456a29d34040cd52cf455277d.zip
Provide proper origin for install event.
Diffstat (limited to 'bundles/org.eclipse.osgi/container/src/org/eclipse/osgi/container/ModuleContainerAdaptor.java')
-rw-r--r--bundles/org.eclipse.osgi/container/src/org/eclipse/osgi/container/ModuleContainerAdaptor.java8
1 files changed, 6 insertions, 2 deletions
diff --git a/bundles/org.eclipse.osgi/container/src/org/eclipse/osgi/container/ModuleContainerAdaptor.java b/bundles/org.eclipse.osgi/container/src/org/eclipse/osgi/container/ModuleContainerAdaptor.java
index e5fc30ad9..daec55e0c 100644
--- a/bundles/org.eclipse.osgi/container/src/org/eclipse/osgi/container/ModuleContainerAdaptor.java
+++ b/bundles/org.eclipse.osgi/container/src/org/eclipse/osgi/container/ModuleContainerAdaptor.java
@@ -30,7 +30,7 @@ public abstract class ModuleContainerAdaptor {
}
/**
* Event types that may be {@link #publishEvent(ModuleEvent, Module) published} for a module
* indicating a {@link Module#getState() state} change has occurred for a module.
*/
public static enum ModuleEvent {
@@ -114,8 +114,12 @@ public abstract class ModuleContainerAdaptor {
* No locks are held by the container when this method is called
* @param type the event type to publish
* @param module the module the event is associated with
+ * @param origin the module which is the origin of the event. For the event
+ * type {@link ModuleEvent#INSTALLED}, this is the module whose context was used
+ * to install the module. Otherwise it is the module itself. May be null only
+ * when the event is not of type {@link ModuleEvent#INSTALLED}.
*/
- public abstract void publishEvent(ModuleEvent type, Module module);
+ public abstract void publishModuleEvent(ModuleEvent type, Module module, Module origin);
/**
* Returns the specified configuration property value
@@ -30,7 +30,7 @@ public abstract class ModuleContainerAdaptor {
}
/**
- * Event types that may be {@link #publishEvent(ModuleEvent, Module) published} for a module
+ * Event types that may be {@link #publishModuleEvent(ModuleEvent, Module, Module) published} for a module
* indicating a {@link Module#getState() state} change has occurred for a module.
*/

Back to the top